@@ -238,6 +238,21 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
   TE <- x$TE[o]
   seTE <- x$seTE[o]
   #
+  if (!is.null(x$cluster))
+    cluster <- x$cluster[o]
+  else
+    cluster <- NULL
+  #
+  if (!is.null(x$weights.common))
+    weights.common <- x$weights.common[o]
+  else
+    weights.common <- NULL
+  #
+  if (!is.null(x$weights.random))
+    weights.random <- x$weights.random[o]
+  else
+    weights.random <- NULL
+  #
   incr.e <- x$incr.e[o]
   incr.c <- x$incr.c[o]
   #
@@ -344,7 +359,12 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metabin(event.e[sel], n.e[sel], event.c[sel], n.c[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    method = x$method, sm = x$sm,
                    #
                    incr.e = incr.e[sel], incr.c = incr.c[sel],
@@ -357,6 +377,7 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -374,7 +395,12 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     n.c[sel], mean.c[sel], sd.c[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     sm = x$sm,
                     pooledvar = replaceNA(x$pooledvar, gs("pooledvar")),
                     ##
@@ -382,6 +408,7 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -398,13 +425,19 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metacor(cor[sel], n[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    sm = x$sm, null.effect = x$null.effect,
                    ##
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -420,13 +453,19 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metagen(TE[sel], seTE[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    sm = x$sm, null.effect = x$null.effect,
                    ##
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -444,7 +483,12 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                    event.c[sel], time.c[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    method = x$method, sm = x$sm,
                    #
                    incr.e = incr.e[sel], incr.c = incr.c[sel],
@@ -455,6 +499,7 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -471,13 +516,19 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metamean(n[sel], mean[sel], sd[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     sm = x$sm, null.effect = x$null.effect,
                     ##
                     method.tau = x$method.tau,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -494,7 +545,12 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metaprop(event[sel], n[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     method = x$method, sm = x$sm, null.effect = x$null.effect,
                     ##
                     incr = incr.i, method.incr = x$method.incr,
@@ -504,6 +560,7 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -520,7 +577,12 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metarate(event[sel], time[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     method = x$method, sm = x$sm, null.effect = x$null.effect,
                     ##
                     incr = incr.i, method.incr = x$method.incr,
@@ -529,6 +591,7 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -841,6 +904,7 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
               method = x$method,
               method.random = x$method.random,
               #
+              method.common.ci = x$method.common.ci,
               method.random.ci = x$method.random.ci,
               adhoc.hakn.ci = x$adhoc.hakn.ci,
               #
@@ -919,6 +983,16 @@ metainf.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
               ##
               call = match.call())
   #
+  if (!is.null(weights.common) & pooled == "common") {
+    res$weights.common <- TRUE
+    res$weights.random <- FALSE
+  }
+  #
+  if (!is.null(weights.random) & pooled == "random") {
+    res$weights.common <- FALSE
+    res$weights.random <- TRUE
+  }
+  #
   if (run_cidprop) {
     res$cid.below.null <- pp$cid.below.null
     res$cid.above.null <- pp$cid.above.null
