@@ -21,6 +21,9 @@
 #'   from the same cluster resulting in the use of a three-level
 #'   meta-analysis model.
 #' @param rho Assumed correlation of estimates within a cluster.
+#' @param weights A single numeric or vector with user-specified weights.
+#' @param weights.common User-specified weights (common effect model).
+#' @param weights.random User-specified weights (random effects model).
 #' @param method A character string indicating which method is to be
 #'   used for pooling of studies. One of \code{"Inverse"} and
 #'   \code{"GLMM"}, can be abbreviated.
@@ -74,6 +77,9 @@
 #'   (see \code{\link{meta-package}}).
 #' @param level.ma The level used to calculate confidence intervals
 #'   for meta-analysis estimates.
+#' @param method.common.ci A character string indicating which method
+#'   is used to calculate confidence interval and test statistic for
+#'   common effect estimate (see \code{\link{meta-package}}).
 #' @param method.random.ci A character string indicating which method
 #'   is used to calculate confidence interval and test statistic for
 #'   random effects estimate (see \code{\link{meta-package}}).
@@ -258,7 +264,9 @@
 #' \code{incr}). This continuity correction is used both to calculate
 #' individual study results with confidence limits and to conduct
 #' meta-analysis based on the inverse variance method. For GLMMs no
-#' continuity correction is used.
+#' continuity correction is used. Furthermore, the value of \code{incr} is
+#' only considered in the calculation of confidence intervals for individual
+#' studies if \code{method.ci = "NAsm"} (see next subsection).
 #' }
 #' 
 #' \subsection{Confidence intervals for individual studies}{
@@ -285,7 +293,7 @@
 #' confidence interval is calculated for individual studies for any
 #' summary measure (argument \code{sm}) as only number of events and
 #' observations are used in the calculation disregarding the chosen
-#' transformation.
+#' transformation. Furthermore, the continuity correction 
 #'
 #' Results will be presented for transformed proportions if argument
 #' \code{backtransf = FALSE}. In this case, argument \code{method.ci =
@@ -582,6 +590,10 @@ metaprop <- function(event, n, studlab,
                      ##
                      data = NULL, subset = NULL, exclude = NULL,
                      cluster = NULL, rho = 0,
+                     #
+                     weights = NULL,
+                     weights.common = weights, weights.random = weights,
+                     #
                      method,
                      ##
                      sm = gs("smprop"),
@@ -613,6 +625,7 @@ metaprop <- function(event, n, studlab,
                      method.I2 = gs("method.I2"),
                      #
                      level.ma = gs("level.ma"),
+                     method.common.ci = gs("method.common.ci"),
                      method.random.ci = gs("method.random.ci"),
                      adhoc.hakn.ci = gs("adhoc.hakn.ci"),
                      ##
@@ -666,16 +679,27 @@ metaprop <- function(event, n, studlab,
   ##
   
   chknumeric(rho, min = -1, max = 1)
-  ##
+  #
+  chknull(sm)
+  sm <- setchar(sm, gs("sm4prop"))
+  #
   missing.method <- missing(method)
   if (missing.method)
     method <- if (sm == "PLOGIT") "GLMM" else "Inverse"
   else
     method <- setchar(method, gs("meth4prop"))
   is.glmm <- method == "GLMM"
-  ##
-  chknull(sm)
-  sm <- setchar(sm, gs("sm4prop"))
+  #
+  missing.method.common.ci <- missing(method.common.ci)
+  method.common.ci <- setchar(method.common.ci, gs("meth4common.ci"))
+  #
+  if (method != "Inverse" & method.common.ci == "IVhet") {
+    if (!missing.method.common.ci)
+      warning("Argument 'method.common.ci = \"IVhet\"' only available ",
+              "if 'method = \"Inverse\".",
+              call. = FALSE)
+    method.common.ci <- "classic"
+  }
   ##
   missing.method.incr <- missing(method.incr)
   method.incr <- setchar(method.incr, gs("meth4incr"))
@@ -876,6 +900,40 @@ metaprop <- function(event, n, studlab,
   ##
   cluster <- catch("cluster", mc, data, sfsp)
   with.cluster <- !is.null(cluster)
+  #
+  # Catch 'weights', 'weights.common', and 'weights.random' from data:
+  #
+  if (!missing(weights))
+    weights <- catch("weights", mc, data, sfsp)
+  if (!missing(weights.common))
+    weights.common <- catch("weights.common", mc, data, sfsp)
+  if (!missing(weights.random))
+    weights.random <- catch("weights.random", mc, data, sfsp)
+  #
+  if (!is.null(weights) & is.null(weights.common))
+    weights.common <- weights
+  #
+  if (!is.null(weights) & is.null(weights.random))
+    weights.random <- weights
+  #
+  usw.common <- !is.null(weights.common)
+  usw.random <- !is.null(weights.random)
+  #
+  if (usw.common)
+    chknumeric(weights.common, min = 0)
+  #
+  if (usw.random)
+    chknumeric(weights.random, min = 0)
+  #
+  if (usw.common & method != "Inverse")
+    stop("User-specified weights for the common effect model only implemented ",
+         "for the inverse variance method (method = \"Inverse\").",
+         call. = FALSE)
+  #
+  if (usw.random & method == "GLMM")
+    stop("User-specified weights for the random effects model not implemented ",
+         "for generalized linear mixed models (method = \"GLMM\").",
+         call. = FALSE)
   
   
   ##
@@ -886,9 +944,24 @@ metaprop <- function(event, n, studlab,
   
   chklength(n, k.All, fun)
   chklength(studlab, k.All, fun)
+  #
   if (with.cluster)
     chklength(cluster, k.All, fun)
-  ##
+  #
+  if (usw.common) {
+    if (length(weights.common) == 1)
+      weights.common <- rep(weights.common, k.All)
+    else
+      chklength(weights.common, k.All, fun)
+  }
+  #
+  if (usw.random) {
+    if (length(weights.random) == 1)
+      weights.random <- rep(weights.random, k.All)
+    else
+      chklength(weights.random, k.All, fun)
+  }
+  #
   if (length(incr) > 1)
     chklength(incr, k.All, fun)
   ##
@@ -973,6 +1046,12 @@ metaprop <- function(event, n, studlab,
     ##
     if (with.cluster)
       data$.id <- data$.cluster <- cluster
+    #
+    if (usw.common)
+      data$.weights.common <- weights.common
+    #
+    if (usw.random)
+      data$.weights.random <- weights.random
   }
   
   
@@ -990,6 +1069,9 @@ metaprop <- function(event, n, studlab,
     cluster <- cluster[subset]
     exclude <- exclude[subset]
     #
+    weights.common <- weights.common[subset]
+    weights.random <- weights.random[subset]
+    #
     if (length(incr) > 1)
       incr <- incr[subset]
     #
@@ -1264,7 +1346,10 @@ metaprop <- function(event, n, studlab,
   m <- metagen(TE, seTE, studlab,
                exclude = if (missing.exclude) NULL else exclude,
                cluster = cluster, rho = rho,
-               ##
+               #
+               weights.common = weights.common,
+               weights.random = weights.random,
+               #
                sm = sm,
                level = level,
                ##
@@ -1285,6 +1370,7 @@ metaprop <- function(event, n, studlab,
                method.I2 = method.I2,
                #
                level.ma = level.ma,
+               method.common.ci = method.common.ci,
                method.random.ci = method.random.ci,
                adhoc.hakn.ci = adhoc.hakn.ci,
                ##
